@@ -1,5 +1,5 @@
 """``kedro.framework.hooks`` provides primitives to use hooks to extend KedroContext's behaviour"""
-from .manager import get_hook_manager
+from .manager import _create_hook_manager
 from .markers import hook_impl
 
-__all__ = ["get_hook_manager", "hook_impl"]
+__all__ = ["_create_hook_manager", "hook_impl"]
