@@ -11,13 +11,25 @@ To run the tests, run ``kedro test`` from the project root directory.
 from pathlib import Path
 
 import pytest
+
+from kedro.framework.project import settings
+from kedro.config import ConfigLoader
 from kedro.framework.context import KedroContext
+from kedro.framework.hooks import _create_hook_manager
 
 
 @pytest.fixture
-def project_context():
+def config_loader():
+    return ConfigLoader(conf_source=str(Path.cwd() / settings.CONF_SOURCE))
+
+
+@pytest.fixture
+def project_context(config_loader):
     return KedroContext(
-        package_name="{{ cookiecutter.python_package }}", project_path=Path.cwd()
+        package_name="{{ cookiecutter.python_package }}",
+        project_path=Path.cwd(),
+        config_loader=config_loader,
+        hook_manager=_create_hook_manager(),
     )
 
 
